@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 9849a76420ec0adeeeb5039e3411b708
+# configversion: 01e36247aaf22c514fd8932113f77142
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -85,25 +85,22 @@ case "$WMCLASS" in
 			$(test "$SXMO_WM" = dwm && printf %b "$icon_cfg Invert Colors ^ 1 ^ xcalib -a -invert")
 			$icon_clk Change Timezone            ^ 1 ^ sxmo_timezonechange.sh
 			$icon_zzz Auto-suspend $(
-				[ -e "$XDG_CACHE_HOME/sxmo/sxmo.nosuspend" ] && printf "%s" "$icon_tof" || printf "%s" "$icon_ton"
-			) ^ 1 ^ rm "$XDG_CACHE_HOME/sxmo/sxmo.nosuspend" || touch "$XDG_CACHE_HOME/sxmo/sxmo.nosuspend"
+				[ -e "$XDG_CACHE_HOME"/sxmo/sxmo.nosuspend ] && printf "%s" "$icon_tof" || printf "%s" "$icon_ton"
+			) ^ 1 ^ (rm $XDG_CACHE_HOME/sxmo/sxmo.nosuspend || touch $XDG_CACHE_HOME/sxmo/sxmo.nosuspend)
 			$icon_zzz Auto-screen-off $(
 				[ -e "$XDG_CACHE_HOME/sxmo/sxmo.noidle" ] && printf "%s" "$icon_tof" || printf "%s" "$icon_ton"
-			) ^ 1 ^ (rm "$XDG_CACHE_HOME/sxmo/sxmo.noidle" || touch "$XDG_CACHE_HOME/sxmo/sxmo.noidle") && sxmo_hook_unlock.sh
+			) ^ 1 ^ (rm $XDG_CACHE_HOME/sxmo/sxmo.noidle || touch $XDG_CACHE_HOME/sxmo/sxmo.noidle) && sxmo_hook_unlock.sh
 			$icon_ror Autorotate $(
 				sxmo_daemons.sh running autorotate -q &&
 				printf "%s" "$icon_ton" || printf "%s" "$icon_tof"
 			) ^ 1 ^ toggle_daemon 'Autorotate' autorotate sxmo_autorotate.sh
-			$icon_lck Proximity Lock $(
-				sxmo_daemons.sh running proximity_lock -q &&
-				printf "%s" "$icon_ton" || printf "%s" "$icon_tof"
-			) ^ 1 ^ toggle_daemon 'Proximity Lock' proximity_lock sxmo_hook_proximitylock.sh
 			$icon_ror Rotate                     ^ 1 ^ sxmo_rotate.sh rotate
 			$icon_trm Hooks                      ^ 0 ^ sxmo_hookmenu.sh
 			$icon_upc Upgrade Pkgs               ^ 0 ^ sxmo_terminal.sh sxmo_upgrade.sh
 			$icon_sfl Migrate configuration      ^ 0 ^ sxmo_terminal.sh sxmo_migrate.sh
 			$icon_cfg Edit configuration         ^ 0 ^ sxmo_terminal.sh $EDITOR $XDG_CONFIG_HOME/sxmo/$(test "$SXMO_WM" = sway && printf sway || printf xinit)
 			$(command -v pmos-tweaks >/dev/null && echo "$icon_cfg PostmarketOS Tweaks	     ^ 0 ^ GDK_SCALE=1 pmos-tweaks")
+			$icon_cfg Suspend Blockers           ^ 0 ^ sxmo_terminal.sh sxmo_wakelock.sh debug watch
 			$icon_inf Version                    ^ 0 ^ sxmo_terminal.sh sxmo_version.sh --block
 		"
 		WINNAME=Config
@@ -113,7 +110,6 @@ case "$WMCLASS" in
 		CHOICES="
 			$icon_lck Lock               ^ 0 ^ sxmo_hook_lock.sh
 			$icon_lck Lock (Screen off)  ^ 0 ^ sxmo_hook_screenoff.sh
-			$icon_zzz Suspend            ^ 0 ^ sxmo_hook_screenoff.sh && sxmo_suspend.sh
 			$icon_out Logout             ^ 0 ^ confirm Logout && sxmo_power.sh logout
 			$([ -f "$(xdg_data_path xsessions/sxmo.desktop)" ] &&
 				[ -f "$(xdg_data_path wayland-sessions/swmo.desktop)" ] &&
@@ -208,7 +204,7 @@ case "$WMCLASS" in
 		"
 		WINNAME=St
 		;;
-	*foot*|*st*|*terminal*)
+	*foot*|*st*|*terminal*|org.gnome.vte.application)
 		# First we try to handle the app running inside the terminal:
 		WMNAME="${1:-$(printf %s "$XPROPOUT" | grep title: | cut -d" " -f2- | tr '[:upper:]' '[:lower:]')}"
 		if printf %s "$WMNAME" | grep -qi -E -w "(vi|vim|vis|nvim|neovim|kakoune)"; then
@@ -449,10 +445,14 @@ case "$WMCLASS" in
 						$icon_ard Scroll down     ^ 1 ^ sxmo_type -M Shift -k Next
 						$icon_lnk URL Mode        ^ 0 ^ sxmo_type -M Shift -M Ctrl -k u
 						$icon_kbd Hotkeys         ^ 0 ^ sxmo_appmenu.sh sthotkeys
+						$icon_fnd Search Field	  ^ 0 ^ sxmo_type -M Ctrl -M Shift -k r
+						$icon_aru Search Back	  ^ 0 ^ sxmo_type -M Ctrl -k r
+						$icon_ard Search Forward  ^ 0 ^ sxmo_type -M Ctrl -k s
+						$icon_itm Search Extend	  ^ 0 ^ sxmo_type -M Ctrl -k w
 					"
 					WINNAME=Foot
 					;;
-				*terminal*)
+				*terminal*|org.gnome.vte.application)
 					CHOICES="$icon_kbd Hotkeys ^ 0 ^ sxmo_appmenu.sh sthotkeys"
 					WINNAME=Terminal
 					;;
@@ -555,7 +555,7 @@ case "$WMCLASS" in
 		"
 		WINNAME=Falkon
 		;;
-	*firefox*)
+	*firefox*|*navigator*)
 		# Firefox
 		CHOICES="
 			$icon_flt Pipe URL          ^ 0 ^ sxmo_urlhandler.sh
@@ -638,6 +638,7 @@ case "$WMCLASS" in
 		CHOICES="
 			$icon_grd Scripts                                            ^ 0 ^ sxmo_appmenu.sh scripts
 			$icon_grd Apps                                               ^ 0 ^ sxmo_appmenu.sh applications
+			$icon_grd Binaries                                           ^ 0 ^ sxmo_brun.sh
 			$icon_dir Files                                              ^ 0 ^ sxmo_files.sh
 			$icon_phn Dialer                                             ^ 0 ^ sxmo_modemdial.sh
 			$icon_msg Texts                                              ^ 0 ^ sxmo_modemtext.sh
@@ -650,7 +651,7 @@ case "$WMCLASS" in
 			$(
 				if [ -z "$SXMO_DISABLE_LEDS" ]; then
 					printf "%s Flashlight " "$icon_fll"
-					sxmo_uniq_exec.sh sxmo_led.sh get white | grep -vq ^100$ &&
+					sxmo_led.sh get white | grep -vq ^100$ &&
 						printf %b "$icon_tof" ||  printf %b "$icon_ton";
 					printf %b "^ 1 ^ sxmo_flashtoggle.sh"
 				fi
