@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 98091b5867c68e509fe196f47387f5e0
+# configversion: b4c50b1494528d1671fc7c807ab4aafa
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -15,56 +15,58 @@
 
 icon_a2x="⇄"
 icon_a2y="⇅"
-icon_ac1=""
-icon_ac2=""
-icon_ac3=""
-icon_ac4=""
+icon_ac1="↖"
+icon_ac2="↗"
+icon_ac3="↘"
+icon_ac4="↙"
 icon_and=""
-icon_ard=""
-icon_arl=""
-icon_arr=""
-icon_aru=""
+icon_ard="↓"
+icon_arl="←"
+icon_arr="→"
+icon_aru="↑"
 icon_att=""
+icon_audio="♫"
 icon_bel=""
 icon_bok=""
+icon_brightness="󰃝"
 icon_bth="" # bluetooth
 icon_cal=""
 icon_cam=""
 icon_cfg="" #configuration cog
 icon_chk=""
 icon_chs="♜" #chess
-icon_clc="" #calculator
-icon_clk=""
-icon_cls="" #close
-icon_com="" # (Laptop) Computer (💻)
+icon_clc="󰃬" #calculator
+icon_clk="󰥔"
+icon_cls="󰅖" #close
+icon_com="" # (Laptop) Computer (💻)
 icon_cpy=""
-icon_del="﫧" #delete
+icon_del="󰅖" #delete
 icon_dir="" #directory folder
 icon_dof="" # dot off
 icon_don="" # dot on
 icon_dop="" # dot point
-icon_dot="" # searching, connecting, etc.
-icon_drw="" # Drawing tablet
+icon_dot="󰇘" # searching, connecting, etc.
+icon_drw="󰏬" # Drawing tablet
 icon_ear="" # earpiece
-icon_edt="" #editor
-icon_eml="" #email
-icon_exp="" #expand
+icon_edt="󰎞" #editor
+icon_eml="󰇮" #email
+icon_exp="󰁌" #expand
 icon_fbw=""
 icon_ffw="" #fast forward
 icon_ffx="" #firefox
 icon_fil="" #file
 icon_flk="" #falkon
-icon_fll="" #flashlight
+icon_fll="󰉄" #flashlight
 icon_flt="" #filter/pipe
 icon_fnd="" #search/find
-icon_gam="" # gaming controller (🎮)
+icon_gam="󰊴" # gaming controller (🎮)
 icon_glb="" #globe
 icon_gps='' #gps
-icon_grd=""
+icon_grd="󰀻"
 icon_grp="" #group
 icon_hdp="" #headphones
 icon_hom=""
-icon_img=""
+icon_img="󰏜"
 icon_inf="" #info
 icon_itm="" #item (default)
 icon_kbd="" #keyboard
@@ -72,41 +74,41 @@ icon_key=""
 icon_lck=""
 icon_lnk=""
 icon_lst="" #list
-icon_map=""
-icon_mdd="" # modem disabled state
-icon_mic=""
-icon_mmc=""
+icon_map="󰍍"
+icon_mdd="󰄢" # modem disabled state
+icon_mic="󰍬"
+icon_mmc="󰍭"
 icon_mnu=""
 icon_mod="" # modem
-icon_mov=""
-icon_mse="" # computer mouse (🖱️)
-icon_msg="" #text
-icon_mus=""
+icon_mov="󰁁"
+icon_mse="󰍽" # computer mouse (🖱️)
+icon_msg="󰍦" #text
+icon_mus="󰎈"
 icon_mut="" #mute
-icon_mvi="" #movie
-icon_net=""
+icon_mvi="󰎁" #movie
+icon_net="󰀂"
 icon_nto="" #no touch
 icon_nxt="" #next
-icon_out="" #logout
+icon_out="󰍃" #logout
 icon_pau=""
-icon_phl="" #phonelog
-icon_phn="" #phone
-icon_phx="" #hangup
-icon_plk="" # phone locked
+icon_phl="󰏹" #phonelog
+icon_phn="󰏲" #phone
+icon_phx="󰏵" #hangup
+icon_plk="󰏸" # phone locked
 icon_pls=""
-icon_prn="🖶" # printer (🖨️)
+icon_prn="" # printer (🖨️)
 icon_prv="" #previous
 icon_pst=""
 icon_pwr="⏻" #power
 icon_red="" #reddit
-icon_ret="" #return
+icon_ret="󰌑" #return
 icon_rld=""
 icon_rol="" #rotate left
 icon_ror="" #rotate right
 icon_rss=""
-icon_sav="" #save
+icon_sav="󰆓" #save
 icon_sfl="" #shuffle, random
-icon_shr="" #shrink
+icon_shr="󰁄" #shrink
 icon_snd="" #send
 icon_spk="" #speaker
 icon_spl=""
@@ -115,19 +117,19 @@ icon_stp="" #stop
 icon_str="" #star
 icon_tab=""
 icon_tgm='' #telegram
-icon_tmr="" #timer
+icon_tmr="󰀠" #timer
 icon_tof=""
 icon_ton=""
 icon_trh="" # trash
 icon_trm='' #terminal
-icon_upc="" #up in circle
+icon_upc="󰁠" #up in circle
 icon_usb="" # usb
-icon_usr=""
+icon_usr="󰀄"
 icon_vid="" #video
 icon_vim=''
 icon_wif=""
-icon_wfo="睊" # wifi off
-icon_wfh="" # wifi hotspot
+icon_wfo="󰖪" # wifi off
+icon_wfh="󰀂" # wifi hotspot
 icon_win="" #window
 icon_wat="" # watch (⌚)
 icon_wn2=""
@@ -161,7 +163,7 @@ icon_modem_threeg="󰜓" # a lot (see sxmo_hook_statusbar.sh)
 icon_modem_hspa="󰜕" # hspa
 icon_modem_hspa_plus="󰜖" # hspa plus
 icon_modem_twog="󰜒" # edge, pots, gsm, gprs, etc.
-icon_modem_notech="ﲁ" # disabled cell bars
+icon_modem_notech="󰞃" # disabled cell bars
 
 # modem signal strengths
 icon_modem_signal_0="󰢿"
@@ -187,7 +189,7 @@ icon_wifi_disconnected="󰤮"
 icon_bat_c_0="󰢟"
 icon_bat_c_1="󱊤"
 icon_bat_c_2="󱊥"
-icon_bat_c_3=""
+icon_bat_c_3="󰂅"
 icon_bat_0="󰂎"
 icon_bat_1="󱊡"
 icon_bat_2="󱊢"
