@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 222a2c8ed5dc56c6f25395dcb094960e
+# configversion: 856605ceb9f3e9d64a047d1aae50f505
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -12,6 +12,10 @@ ACTION="$1"
 # shellcheck source=scripts/core/sxmo_common.sh
 . sxmo_common.sh
 
+stop_proximity_lock() {
+	sxmo_daemons.sh stop proximity_lock
+}
+
 # this action will move the lock state $1 levels higher
 lock_screen_action() {
 	count="${1:-1}"
@@ -39,16 +43,23 @@ XPROPOUT="$(sxmo_wm.sh focusedwindow)"
 WMCLASS="$(printf %s "$XPROPOUT" | grep app: | cut -d" " -f2- | tr '[:upper:]' '[:lower:]')"
 WMNAME="$(printf %s "$XPROPOUT" | grep title: | cut -d" " -f2- | tr '[:upper:]' '[:lower:]')"
 
-sxmo_debug "ACTION: $ACTION WMCLASS: $WMCLASS WMNAME: $WMNAME XPROPOUT: $XPROPOUT"
+sxmo_debug "STATE: $(cat "$SXMO_STATE") ACTION: $ACTION WMCLASS: $WMCLASS WMNAME: $WMNAME"
 
 if ! grep -q unlock "$SXMO_STATE"; then
 	case "$ACTION" in
 		"powerbutton_one")
 			lock_screen_action
 			;;
-		"powerbutton_two"|"powerbutton_three")
+		"powerbutton_two")
 			lock_screen_action 2
 			;;
+		"powerbutton_three")
+			if grep -q proximity "$SXMO_STATE"; then
+				stop_proximity_lock
+			else
+				lock_screen_action 2
+			fi
+			;;
 		"voldown_one")
 			sxmo_audio.sh vol down 5
 			exit
@@ -100,7 +111,7 @@ case "$WMCLASS" in
 				;;
 		esac
 		;;
-	*"foot"*|*"st"*|*"vte"*)
+	*"foot"*|*"st"*|*"vte"*|"terminal")
 		# First we try to handle the app running inside st:
 		case "$WMNAME" in
 			*"weechat"*)
@@ -205,6 +216,30 @@ case "$WMCLASS" in
 						;;
 				esac
 				;;
+			*'irssi'*)
+				case "$ACTION" in
+					"onedown")
+						sxmo_type.sh -M Alt p
+						exit 0
+						;;
+					"oneup")
+						sxmo_type.sh -M Alt n
+						exit 0
+						;;
+				esac
+				;;
+			*'gomuks'*)
+				case "$ACTION" in
+					*"oneup")
+						sxmo_type.sh -k Page_Down
+						exit 0
+						;;
+					*"onedown")
+						sxmo_type.sh -k Page_Up
+						exit 0
+						;;
+				esac
+				;;
 		esac
 		# Now we try generic actions for terminal
 		case "$ACTION" in
@@ -232,6 +267,24 @@ case "$WMCLASS" in
 						;;
 				esac
 				;;
+			"uprightedge")
+				case "$WMCLASS" in
+					"org.gnome.vte.application"|"terminal")
+						# For VTE, fallback to doing nothing,
+						# you're probably dragging the scrollbar
+						exit 0
+						;;
+				esac
+				;;
+			"downrightedge")
+				case "$WMCLASS" in
+					"org.gnome.vte.application"|"terminal")
+						# For VTE, fallback to doing nothing,
+						# you're probably dragging the scrollbar
+						exit 0
+						;;
+				esac
+				;;
 		esac
 esac
 
@@ -250,7 +303,11 @@ case "$ACTION" in
 		exit 0
 		;;
 	"powerbutton_three")
-		sxmo_terminal.sh
+		if grep -q proximity "$SXMO_STATE"; then
+			stop_proximity_lock
+		else
+			sxmo_terminal.sh
+		fi
 		exit 0
 		;;
 	"voldown_one")
@@ -371,6 +428,9 @@ case "$ACTION" in
 		exit 0
 		;;
 	"bottomleftcorner")
+		if grep -q proximity "$SXMO_STATE"; then
+			exit
+		fi
 		sxmo_dmenu.sh close
 		if [ -n "$WMCLASS" ]; then
 			sxmo_hook_lock.sh
